import { Box, Chip, InputAdornment, MenuItem, Slider, Switch, TextField, Typography } from "@mui/material";
import { useAtom } from "jotai";
import { FC } from "react";
import { stagedSettingsAtom } from "../../../../lib/store/jotai/settings";
import { SettingsCategoryTitle } from "../SettingsCategoryTitle";
import { SettingsItem } from "../SettingsItem";

interface SettingsTabWindowProps {
  sx?: any;
}

export const SettingsTabWindow: FC<SettingsTabWindowProps> = ({ sx }) => {
  // atoms
  const [stagedSettings, setStagedSettings] = useAtom(stagedSettingsAtom);

  const handleSettingsWindowValueChange = (settingKey: string, settingValue: boolean | number | string | number[]) => {
    const newSettings = {
      ...stagedSettings,
      window: {
        ...stagedSettings.window,
        [settingKey]: settingValue,
      },
    };
    setStagedSettings(newSettings);
  };

  return (
    <Box sx={{ sx }}>
      <SettingsCategoryTitle title="Fullscreen" />
      <SettingsItem
        settingsDescription={
          <>
            <Typography>Fullscreen on startup</Typography>
          </>
        }
        settingsInput={
          <Switch
            checked={stagedSettings.window.start_fullscreen}
            name="start_fullscreen"
            onChange={(e) => {
              handleSettingsWindowValueChange(e.target.name, e.target.checked);
            }}
          />
        }
      />
      <SettingsCategoryTitle title="Titlebar Buttons" />
      <SettingsItem
        settingsDescription={
          <>
            <Typography>Minimize button</Typography>
          </>
        }
        settingsInput={
          <Switch
            checked={stagedSettings.window.minimize_button}
            name="minimize_button"
            onChange={(e) => {
              handleSettingsWindowValueChange(e.target.name, e.target.checked);
            }}
          />
        }
      />
      <SettingsItem
        settingsDescription={
          <>
            <Typography>Maximize button</Typography>
          </>
        }
        settingsInput={
          <Switch
            checked={stagedSettings.window.maximize_button}
            name="maximize_button"
            onChange={(e) => {
              handleSettingsWindowValueChange(e.target.name, e.target.checked);
            }}
          />
        }
      />
    </Box>
  );
};
